@@ -32,7 +32,7 @@
 #ifndef _COMMON_H
 #define _COMMON_H
 
-#define MIXER			"mixer"
+#define ALSA_MIXER			"alsa-mixer"
 #define CACHE_SIZE		"cache_size"
 #define PLUGIN_AUDIO_CACHE_SIZE		"plugin_audio_cache_size"
 #define PLUGIN_VIDEO_CACHE_SIZE		"plugin_video_cache_size"
@@ -67,6 +67,7 @@
 #define SUBTITLESHADOW "subtitleshadow"
 #define SUBTITLE_MARGIN "subtitle_margin"
 #define TRACKER_POSITION "tracker_position"
+#define MOUSE_WHEEL_CHANGES_VOLUME "mouse_wheel_changes_volume"
 
 #define VOLUME	"volume"
 #define AUDIO_CHANNELS "audio_channels"
@@ -79,7 +80,6 @@
 
 #define MPLAYER_BIN		"mplayer_bin"
 #define EXTRAOPTS		"extraopts"
-#define USE_PULSE_FLAT_VOLUME "use_pulse_flat_volume"
 #define USE_XSCRNSAVER "use_xscrnsaver"
 #define MPLAYER_DVD_DEVICE "mplayer_dvd_device"
 
@@ -106,6 +106,7 @@
 #define SHOW_STATUS_ICON "show_status_icon"
 #define SHOW_SUBTITLES "show_subtitles"
 
+#define AUDIO_DEVICE_NAME "audio-device-name"
 
 // JavaScript Playstates
 #define STATE_UNDEFINED     0
@@ -154,9 +155,9 @@ typedef struct _IdleData {
     gdouble percent;
     gdouble cachepercent;
     gint streaming;
+    gboolean seekable;
     gchar progress_text[1024];
     gdouble volume;
-    gint mplayer_volume;
     gboolean mute;
     gchar vol_tooltip[128];
     gint x;
@@ -215,6 +216,7 @@ typedef struct _ThreadData {
     gchar uri[2048];
     gchar filename[1024];
     gchar subtitle[1024];
+    gchar audiofile[1024];
     gint streaming;
     gint player_window;
     gint playlist;
@@ -234,6 +236,7 @@ enum {
     LENGTH_COLUMN,
     LENGTH_VALUE_COLUMN,
     SUBTITLE_COLUMN,
+    AUDIOFILE_COLUMN,
     COVERART_COLUMN,
     AUDIO_CODEC_COLUMN,
     VIDEO_CODEC_COLUMN,
@@ -281,7 +284,7 @@ typedef struct _ButtonDef {
     gchar *hrefid;
 } ButtonDef;
 
-#define METER_BARS 		44
+#define METER_BARS 		40
 gint buckets[METER_BARS];
 gint max_buckets[METER_BARS];
 
@@ -326,8 +329,8 @@ gint stored_window_width, stored_window_height;
 gboolean adjusting;
 gchar vm[10];
 gchar *vo;
-gchar *ao;
-gchar *mixer;
+AudioDevice audio_device;
+gchar *audio_device_name;
 gint audio_channels;
 gboolean use_hw_audio;
 gboolean disable_deinterlace;
@@ -369,6 +372,7 @@ gboolean disable_embeddedfonts;
 gboolean disable_animation;
 gint auto_hide_timeout;
 gboolean always_hide_after_timeout;
+gboolean mouse_over_controls;
 gchar *subtitlefont;
 gdouble subtitle_scale;
 gdouble subtitle_delay;
@@ -382,7 +386,6 @@ gchar *mplayer_bin;
 gchar *mplayer_dvd_device;
 gchar *extraopts;
 gboolean resize_on_new_media;
-gboolean use_pulse_flat_volume;
 gboolean single_instance;
 gboolean new_instance;
 gboolean replace_and_play;
@@ -395,8 +398,11 @@ gchar *gpod_mount_point;
 gboolean disable_cover_art_fetch;
 gboolean updating_recent;
 gboolean large_buttons;
-gint button_size;
+GtkIconSize button_size;
 gboolean use_xscrnsaver;
+gboolean skip_fixed_allocation_on_show;
+gboolean skip_fixed_allocation_on_hide;
+gboolean mouse_wheel_changes_volume;
 
 gboolean remember_loc;
 gboolean use_remember_loc;
@@ -498,6 +504,7 @@ gboolean set_new_lang_menu(gpointer data);
 gboolean set_new_audio_menu(gpointer data);
 gboolean make_panel_and_mouse_invisible(gpointer data);
 gboolean idle_make_button(gpointer data);
+gboolean set_show_seek_buttons(gpointer data);
 void make_button(gchar * src, gchar * href);
 void dbus_open_by_hrefid(gchar * hrefid);
 void dbus_open_next();
@@ -514,7 +521,6 @@ void dbus_disable_screensaver();
 void menuitem_edit_random_callback(GtkMenuItem * menuitem, void *data);
 
 gboolean update_audio_meter(gpointer data);
-gboolean update_volume(gpointer data);
 
 void mplayer_shutdown();
 gpointer launch_player(gpointer data);
@@ -535,5 +541,4 @@ void recent_manager_changed_callback(GtkRecentManager * recent_manager, gpointer
 GValue ALLOW_SHRINK_TRUE;
 GValue ALLOW_SHRINK_FALSE;
 
-
 #endif                          /* _COMMON_H */
