@@ -28,7 +28,9 @@
 #endif
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
+#ifdef X11_ENABLED
 #include <gdk/gdkx.h>
+#endif
 #include "libgmlib/gmlib.h"
 #include "libgmtk/gmtk.h"
 #include <gdk/gdkkeysyms.h>
@@ -82,6 +84,7 @@ GtkMenuItem *menuitem_edit_loop;
 GtkWidget *repeat;
 GtkWidget *shuffle;
 GtkMenuItem *menuitem_edit_switch_audio;
+GtkMenuItem *menuitem_edit_set_audiofile;
 GtkMenuItem *menuitem_edit_select_audio_lang;
 GtkMenu *menu_edit_audio_langs;
 GtkMenuItem *menuitem_edit_set_subtitle;
@@ -172,15 +175,6 @@ GtkWidget *details_audio_bitrate;
 GtkWidget *details_audio_samplerate;
 
 GtkWidget *drawing_area;
-GdkPixbuf *pb_play;
-GdkPixbuf *pb_pause;
-GdkPixbuf *pb_stop;
-GdkPixbuf *pb_ff;
-GdkPixbuf *pb_rew;
-GdkPixbuf *pb_fs;
-GdkPixbuf *pb_next;
-GdkPixbuf *pb_prev;
-GdkPixbuf *pb_menu;
 GdkPixbuf *pb_icon;
 GdkPixbuf *pb_button;
 
@@ -262,6 +256,7 @@ GtkWidget *config_use_xscrnsaver;
 GtkWidget *config_use_mediakeys;
 GtkWidget *config_use_defaultpl;
 GtkWidget *config_disable_animation;
+GtkWidget *config_mouse_wheel;
 
 GtkWidget *config_alang;
 GtkWidget *config_slang;
@@ -344,17 +339,14 @@ void clear_playlist(GtkWidget * widget, void *data);
 void create_playlist_widget();
 void add_folder_to_playlist(GtkWidget * widget, void *data);
 gboolean playlist_drop_callback(GtkWidget * widget, GdkDragContext * dc,
-                                gint x, gint y, GtkSelectionData * selection_data,
-                                guint info, guint t, gpointer data);
+                                gint x, gint y, GtkSelectionData * selection_data, guint info, guint t, gpointer data);
 void create_folder_progress_window();
 void destroy_folder_progress_window();
 void update_status_icon();
 void setup_accelerators();
 void update_details_table();
 gboolean set_software_volume(int *data);
-
-gint get_height();
-gint get_width();
+gboolean set_adjust_layout(gpointer data);
 
 void show_fs_controls();
 void hide_fs_controls();
