@@ -70,7 +70,8 @@ static void gmtk_audio_meter_init(GmtkAudioMeter * meter)
     meter->max_data = NULL;
     meter->data_valid = FALSE;
     meter->max_division_width = -1;
-	gtk_widget_set_double_buffered(GTK_WIDGET(meter), FALSE);
+    gtk_widget_set_double_buffered(GTK_WIDGET(meter), FALSE);
+
 }
 
 static void gmtk_audio_meter_dispose(GObject * object)
@@ -90,6 +91,7 @@ static void gmtk_audio_meter_dispose(GObject * object)
         g_array_free(meter->max_data, TRUE);
         meter->max_data = NULL;
     }
+
 }
 
 
@@ -98,20 +100,27 @@ static void draw(GtkWidget * meter)
     gint i;
     gfloat v;
     gint division_width;
-	GtkAllocation alloc;
+    GtkAllocation alloc;
+    cairo_t *cr;
+    cairo_pattern_t *pattern;
+    GtkStyle *style;
+
+    get_allocation(meter, &alloc);
+    style = gtk_widget_get_style(meter);
 
-	get_allocation(meter,&alloc);
-	
     if (GMTK_AUDIO_METER(meter)->data == NULL)
         return;
 
     division_width = alloc.width / GMTK_AUDIO_METER(meter)->divisions;
     if (division_width < 2)
         division_width = 2;
-    if (GMTK_AUDIO_METER(meter)->max_division_width > 0
-        && division_width > GMTK_AUDIO_METER(meter)->max_division_width)
+    if (GMTK_AUDIO_METER(meter)->max_division_width > 0 && division_width > GMTK_AUDIO_METER(meter)->max_division_width)
         division_width = GMTK_AUDIO_METER(meter)->max_division_width;
 
+    cr = gdk_cairo_create(get_window(meter));
+    cairo_set_antialias(cr, CAIRO_ANTIALIAS_NONE);
+    cairo_set_line_width(cr, 2.0);
+
     for (i = 0; i < GMTK_AUDIO_METER(meter)->divisions; i++) {
         if (GMTK_AUDIO_METER(meter)->max_data) {
             v = g_array_index(GMTK_AUDIO_METER(meter)->max_data, gfloat, i);
@@ -120,19 +129,16 @@ static void draw(GtkWidget * meter)
             if (v <= 0.0)
                 v = 0.0;
 
-            gdk_draw_rectangle(get_window(meter),
-                               gtk_widget_get_style(meter)->dark_gc[0],
-                               TRUE,
-                               i * division_width,
-                               alloc.height * (1.0 - v) + 3,
-                               division_width, alloc.height * v);
+            cairo_set_source_rgb(cr, style->dark[0].red / 65535.0, style->dark[0].green / 65535.0,
+                                 style->dark[0].blue / 65535.0);
+            cairo_rectangle(cr, i * division_width, alloc.height * (1.0 - v) + 3, division_width, alloc.height * v);
+            cairo_fill(cr);
+            cairo_stroke(cr);
 
-            gdk_draw_rectangle(get_window(meter),
-                               gtk_widget_get_style(meter)->mid_gc[3],
-                               FALSE,
-                               i * division_width,
-                               alloc.height * (1.0 - v) + 3,
-                               division_width, alloc.height * v);
+            cairo_set_source_rgb(cr, style->mid[3].red / 65535.0, style->mid[3].green / 65535.0,
+                                 style->mid[3].blue / 65535.0);
+            cairo_rectangle(cr, i * division_width, alloc.height * (1.0 - v) + 3, division_width, alloc.height * v);
+            cairo_stroke(cr);
 
         }
     }
@@ -145,19 +151,22 @@ static void draw(GtkWidget * meter)
         if (v <= 0.0)
             v = 0.00;
 
-        gdk_draw_rectangle(get_window(meter),
-                           gtk_widget_get_style(meter)->mid_gc[3],
-                           TRUE,
-                           i * division_width,
-                           alloc.height * (1.0 - v) + 3,
-                           division_width, alloc.height * v);
+        pattern = cairo_pattern_create_linear(0.0, 0.0, 1.0, (gdouble) alloc.height);
+        cairo_pattern_add_color_stop_rgb(pattern, 0.30, 1.0, 0, 0);
+        cairo_pattern_add_color_stop_rgb(pattern, 0.7, 1.0, 1.0, 0);
+        cairo_pattern_add_color_stop_rgb(pattern, 1.0, 0, 1.0, 0);
 
-        gdk_draw_rectangle(get_window(meter),
-                           gtk_widget_get_style(meter)->fg_gc[0],
-                           FALSE,
-                           i * division_width,
-                           alloc.height * (1.0 - v) + 3,
-                           division_width, alloc.height * v);
+        cairo_set_source_rgb(cr, style->mid[3].red / 65535.0, style->mid[3].green / 65535.0,
+                             style->mid[3].blue / 65535.0);
+        cairo_rectangle(cr, i * division_width, alloc.height * (1.0 - v) + 3, division_width, alloc.height * v);
+        cairo_set_source(cr, pattern);
+        cairo_fill(cr);
+        cairo_stroke(cr);
+        cairo_pattern_destroy(pattern);
+
+        cairo_set_source_rgb(cr, style->fg[0].red / 65535.0, style->fg[0].green / 65535.0, style->fg[0].blue / 65535.0);
+        cairo_rectangle(cr, i * division_width, alloc.height * (1.0 - v) + 3, division_width, alloc.height * v);
+        cairo_stroke(cr);
 
     }
 /*
@@ -165,17 +174,20 @@ static void draw(GtkWidget * meter)
                        gtk_widget_get_style(meter)->text_aa_gc[0],
                        FALSE, 0, 0, meter->allocation.width - 1, meter->allocation.height - 1);
 */
+    cairo_set_source_rgb(cr, style->text_aa[0].red / 65535.0, style->text_aa[0].green / 65535.0,
+                         style->text_aa[0].blue / 65535.0);
 
-    gdk_draw_line(get_window(meter), gtk_widget_get_style(meter)->text_aa_gc[0], 0,
-                  alloc.height - 1, alloc.width - 1,
-                  alloc.height - 1);
+    cairo_move_to(cr, 0, alloc.height - 1);
+    cairo_line_to(cr, alloc.width - 1, alloc.height - 1);
+
+    cairo_destroy(cr);
 }
 
 static gboolean gmtk_audio_meter_expose(GtkWidget * meter, GdkEventExpose * event)
 {
     PangoLayout *p;
 
-	gdk_window_begin_paint_region(get_window(meter),event->region);
+    gdk_window_begin_paint_region(get_window(meter), event->region);
     if (GMTK_AUDIO_METER(meter)->data_valid) {
         draw(meter);
     } else {
@@ -183,7 +195,7 @@ static gboolean gmtk_audio_meter_expose(GtkWidget * meter, GdkEventExpose * even
         gdk_draw_layout(get_window(meter), gtk_widget_get_style(meter)->black_gc, 0, 0, p);
         g_object_unref(p);
     }
-	gdk_window_end_paint(get_window(meter));
+    gdk_window_end_paint(get_window(meter));
     return FALSE;
 }
 
