@@ -64,7 +64,7 @@ static GOptionEntry entries[] = {
     {"volume_softvol", 0, 0, G_OPTION_ARG_INT, &volume_softvol,
      N_("Last software volume percentage- only applied when remember_softvol is set to TRUE"),
      NULL},
-    {"mixer", 0, 0, G_OPTION_ARG_STRING, &mixer, N_("Mixer to use"), NULL},
+    {"mixer", 0, 0, G_OPTION_ARG_STRING, &(audio_device.alsa_mixer), N_("Mixer to use"), NULL},
     {"volume", 0, 0, G_OPTION_ARG_INT, &volume, N_("Set initial volume percentage"), NULL},
     {"showcontrols", 0, 0, G_OPTION_ARG_INT, &showcontrols, N_("Show the controls in window"),
      "[0|1]"},
@@ -202,6 +202,7 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
     GtkWidget *dialog;
     gchar *error_msg = NULL;
     gchar *subtitle = NULL;
+    gchar *audiofile = NULL;
     GtkTreePath *path;
     gchar *local_file = NULL;
     gchar *uri = NULL;
@@ -242,8 +243,8 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
                            DEMUXER_COLUMN, &demuxer,
                            COVERART_COLUMN, &pixbuf,
                            SUBTITLE_COLUMN, &subtitle,
-                           COUNT_COLUMN, &count, PLAYLIST_COLUMN, &playlist,
-                           PLAYABLE_COLUMN, &playable, -1);
+                           AUDIOFILE_COLUMN, &audiofile,
+                           COUNT_COLUMN, &count, PLAYLIST_COLUMN, &playlist, PLAYABLE_COLUMN, &playable, -1);
         if (GTK_IS_TREE_SELECTION(selection)) {
             path = gtk_tree_model_get_path(GTK_TREE_MODEL(playliststore), playiter);
             if (path) {
@@ -291,6 +292,7 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
                 g_free(video_codec);
                 g_free(demuxer);
                 g_free(subtitle);
+                g_free(audiofile);
                 if (gtk_list_store_iter_is_valid(playliststore, playiter)) {
                     gtk_tree_model_get(GTK_TREE_MODEL(playliststore), playiter, LENGTH_VALUE_COLUMN,
                                        &length_value, DESCRIPTION_COLUMN, &title, ARTIST_COLUMN,
@@ -298,8 +300,9 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
                                        &audio_codec, VIDEO_CODEC_COLUMN, &video_codec,
                                        VIDEO_WIDTH_COLUMN, &width, VIDEO_HEIGHT_COLUMN, &height,
                                        DEMUXER_COLUMN, &demuxer, COVERART_COLUMN, &pixbuf,
-                                       SUBTITLE_COLUMN, &subtitle, COUNT_COLUMN, &count,
-                                       PLAYLIST_COLUMN, &playlist, PLAYABLE_COLUMN, &playable, -1);
+                                       SUBTITLE_COLUMN, &subtitle, AUDIOFILE_COLUMN, &audiofile,
+                                       COUNT_COLUMN, &count, PLAYLIST_COLUMN, &playlist,
+                                       PLAYABLE_COLUMN, &playable, -1);
                     if (!playable) {
                         if (verbose)
                             printf("%s is not marked as playable (%i)\n", uri, i);
@@ -359,8 +362,7 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
     message = g_strconcat(message, "</small>", NULL);
 
     // probably not much cover art for random video files
-    if (pixbuf == NULL && video_codec == NULL && !streaming_media(uri) && control_id == 0
-        && !playlist) {
+    if (pixbuf == NULL && video_codec == NULL && !streaming_media(uri) && control_id == 0 && !playlist) {
         metadata = (MetaData *) g_new0(MetaData, 1);
         metadata->uri = g_strdup(uri);
         if (title != NULL)
@@ -429,6 +431,10 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
         g_strlcpy(thread_data->subtitle, subtitle, 1024);
         g_free(subtitle);
     }
+    if (audiofile != NULL) {
+        g_strlcpy(thread_data->audiofile, audiofile, 1024);
+        g_free(audiofile);
+    }
 #if GTK2_12_ENABLED
     volume = gtk_scale_button_get_value(GTK_SCALE_BUTTON(vol_slider));
 #else
@@ -465,8 +471,7 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
         file = g_file_new_for_uri(uri);
         file_info = g_file_query_info(file,
                                       G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE ","
-                                      G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
-                                      G_FILE_QUERY_INFO_NONE, NULL, NULL);
+                                      G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME, G_FILE_QUERY_INFO_NONE, NULL, NULL);
 
 
         if (file_info) {
@@ -597,23 +602,27 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
     return 0;
 }
 
+#ifndef OS_WIN32
 static void hup_handler(int signum)
 {
     // printf("handling signal %i\n",signum);
     delete_callback(NULL, NULL, NULL);
 }
+#endif
 
 int main(int argc, char *argv[])
 {
     struct stat buf;
     struct mntent *mnt = NULL;
-    FILE *fp;
+    FILE *fp = NULL;
     gchar *uri;
     gint fileindex = 1;
     GError *error = NULL;
     GOptionContext *context;
     gint i;
+#ifndef OS_WIN32
     struct sigaction sa;
+#endif
     gboolean playiter = FALSE;
 
 #ifdef GIO_ENABLED
@@ -707,6 +716,7 @@ int main(int argc, char *argv[])
     disable_pause_on_click = FALSE;
     disable_animation = FALSE;
     auto_hide_timeout = 3;
+    mouse_over_controls = FALSE;
     use_mediakeys = TRUE;
     use_defaultpl = FALSE;
     mplayer_bin = NULL;
@@ -726,17 +736,14 @@ int main(int argc, char *argv[])
     gpod_mount_point = NULL;
     load_tracks_from_gpod = FALSE;
     disable_cover_art_fetch = FALSE;
-    mixer = NULL;
     fullscreen = 0;
-    ao = NULL;
     vo = NULL;
-    use_pulse_flat_volume = FALSE;
     dvdnav_title_is_menu = FALSE;
     data = NULL;
     max_data = NULL;
     details_table = NULL;
     large_buttons = FALSE;
-    button_size = 16;
+    button_size = GTK_ICON_SIZE_BUTTON;
     lastguistate = -1;
     non_fs_height = 0;
     non_fs_width = 0;
@@ -748,17 +755,29 @@ int main(int argc, char *argv[])
     screensaver_disabled = FALSE;
     update_control_flag = FALSE;
     gchar *filename;
+    skip_fixed_allocation_on_show = FALSE;
+    skip_fixed_allocation_on_hide = FALSE;
 
+#ifndef OS_WIN32
     sa.sa_handler = hup_handler;
     sigemptyset(&sa.sa_mask);
+#ifdef SA_RESTART
     sa.sa_flags = SA_RESTART;   /* Restart functions if
                                    interrupted by handler */
+#endif
+#ifdef SIGINT
     if (sigaction(SIGINT, &sa, NULL) == -1)
         printf("SIGINT signal handler not installed\n");
+#endif
+#ifdef SIGHUP
     if (sigaction(SIGHUP, &sa, NULL) == -1)
         printf("SIGHUP signal handler not installed\n");
+#endif
+#ifdef SIGTERM
     if (sigaction(SIGTERM, &sa, NULL) == -1)
         printf("SIGTERM signal handler not installed\n");
+#endif
+#endif
 
     // call g_type_init or otherwise we can crash
     g_type_init();
@@ -781,13 +800,12 @@ int main(int argc, char *argv[])
     g_free(uri);
     uri = NULL;
 
-    default_playlist =
-        g_strdup_printf("file://%s/gnome-mplayer/default.pls", g_get_user_config_dir());
+    default_playlist = g_strdup_printf("file://%s/gnome-mplayer/default.pls", g_get_user_config_dir());
     safe_to_save_default_playlist = TRUE;
 
     gm_store = gm_pref_store_new("gnome-mplayer");
     gmp_store = gm_pref_store_new("gecko-mediaplayer");
-    mixer = gm_pref_store_get_string(gm_store, MIXER);
+    audio_device.alsa_mixer = gm_pref_store_get_string(gm_store, ALSA_MIXER);
     osdlevel = gm_pref_store_get_int(gm_store, OSDLEVEL);
     pplevel = gm_pref_store_get_int(gm_store, PPLEVEL);
 #ifndef HAVE_ASOUNDLIB
@@ -816,8 +834,7 @@ int main(int argc, char *argv[])
     disable_embeddedfonts = gm_pref_store_get_boolean(gm_store, DISABLEEMBEDDEDFONTS);
     disable_pause_on_click = gm_pref_store_get_boolean(gm_store, DISABLEPAUSEONCLICK);
     disable_animation = gm_pref_store_get_boolean(gm_store, DISABLEANIMATION);
-    auto_hide_timeout =
-        gm_pref_store_get_int_with_default(gm_store, AUTOHIDETIMEOUT, auto_hide_timeout);
+    auto_hide_timeout = gm_pref_store_get_int_with_default(gm_store, AUTOHIDETIMEOUT, auto_hide_timeout);
     disable_cover_art_fetch = gm_pref_store_get_boolean(gm_store, DISABLE_COVER_ART_FETCH);
     use_mediakeys = gm_pref_store_get_boolean_with_default(gm_store, USE_MEDIAKEYS, use_mediakeys);
     use_defaultpl = gm_pref_store_get_boolean_with_default(gm_store, USE_DEFAULTPL, use_defaultpl);
@@ -855,9 +872,7 @@ int main(int argc, char *argv[])
     }
     mplayer_dvd_device = gm_pref_store_get_string(gm_store, MPLAYER_DVD_DEVICE);
     extraopts = gm_pref_store_get_string(gm_store, EXTRAOPTS);
-    use_pulse_flat_volume = gm_pref_store_get_boolean(gm_store, USE_PULSE_FLAT_VOLUME);
-    use_xscrnsaver =
-        gm_pref_store_get_boolean_with_default(gm_store, USE_XSCRNSAVER, use_xscrnsaver);
+    use_xscrnsaver = gm_pref_store_get_boolean_with_default(gm_store, USE_XSCRNSAVER, use_xscrnsaver);
 
     remember_loc = gm_pref_store_get_boolean(gm_store, REMEMBER_LOC);
     loc_window_x = gm_pref_store_get_int(gm_store, WINDOW_X);
@@ -868,6 +883,12 @@ int main(int argc, char *argv[])
 
     keep_on_top = gm_pref_store_get_boolean(gm_store, KEEP_ON_TOP);
     resize_on_new_media = gm_pref_store_get_boolean(gm_store, RESIZE_ON_NEW_MEDIA);
+    mouse_wheel_changes_volume = gm_pref_store_get_boolean_with_default(gm_store, MOUSE_WHEEL_CHANGES_VOLUME, FALSE);
+
+    audio_device_name = gm_pref_store_get_string(gm_store, AUDIO_DEVICE_NAME);
+    audio_device.description = g_strdup(audio_device_name);
+
+
     read_mplayer_config();
 
     context = g_option_context_new(_("[FILES...] - GNOME Media player based on MPlayer"));
@@ -913,6 +934,10 @@ int main(int argc, char *argv[])
 
     read_mplayer_config();
 
+    if (verbose && embed_window) {
+        printf("embedded in window id 0x%x\n", embed_window);
+    }
+
     if (verbose && single_instance) {
         printf("Running in single instance mode\n");
     }
@@ -926,62 +951,32 @@ int main(int argc, char *argv[])
         printf("Running with panscan enabled (mplayer svn r29565 or higher required)\n");
     }
 #endif
-
-    if (ao != NULL && g_ascii_strncasecmp(ao, "pulse", strlen("pulse")) == 0) {
-        // do nothing
-    } else {
-        // we have alsa or pulse flat volume now
-        use_pulse_flat_volume = TRUE;
-    }
-
-    if (volume == -1) {
-        volume = (gint) get_alsa_volume(TRUE);
-        if (!use_pulse_flat_volume) {
-            if (ao != NULL && g_ascii_strncasecmp(ao, "pulse", strlen("pulse")) == 0) {
-                if (verbose)
-                    printf
-                        ("Using pulse audio in non-flat volume mode, setting volume to max (will be limited by mixer 100%% of %i%%)\n",
-                         volume);
-                volume = 100;
-            }
-        }
-    } else {
-        if (verbose)
-            printf("Using volume of %i from gnome-mplayer preference\n", volume);
+    if (verbose) {
+        printf("Using audio device: %s\n", audio_device_name);
     }
 
     if (softvol) {
+        if (verbose)
+            printf("Using MPlayer Software Volume control\n");
         if (remember_softvol && volume_softvol != -1) {
             if (verbose)
-                printf
-                    ("Using softvol, since remember_softvol is enabled volume will be set to %i%% of %i%%\n",
-                     volume_softvol, volume);
+                printf("Using last volume of %i%%\n", volume_softvol);
             volume = (gdouble) volume_softvol;
         } else {
-            if (verbose)
-                printf
-                    ("Using softvol, setting volume to max (will be limited by mixer 100%% of %i%%)\n",
-                     volume);
             volume = 100;
         }
     }
 
-    if (volume >= 0 && volume <= 100) {
-        idledata->volume = (gdouble) volume;
-    }
-
-    use_volume_option = detect_volume_option();
 
     if (large_buttons)
-        button_size = 48;
+        button_size = GTK_ICON_SIZE_DIALOG;
 
     if (playlist_visible && control_id != 0)
         playlist_visible = FALSE;
 
     if (error != NULL) {
         printf("%s\n", error->message);
-        printf(_
-               ("Run 'gnome-mplayer --help' to see a full list of available command line options.\n"));
+        printf(_("Run 'gnome-mplayer --help' to see a full list of available command line options.\n"));
         return 1;
     }
 
@@ -998,9 +993,9 @@ int main(int argc, char *argv[])
     playliststore =
         gtk_list_store_new(N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT,
                            G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_FLOAT, G_TYPE_STRING,
-                           G_TYPE_POINTER, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT,
-                           G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_FLOAT, G_TYPE_FLOAT,
-                           G_TYPE_BOOLEAN);
+                           G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING, G_TYPE_STRING,
+                           G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT,
+                           G_TYPE_FLOAT, G_TYPE_FLOAT, G_TYPE_BOOLEAN);
 
     create_window(embed_window);
 
@@ -1046,6 +1041,7 @@ int main(int argc, char *argv[])
         if (S_ISBLK(buf.st_mode)) {
             // might have a block device, so could be a DVD
 
+#ifdef HAVE_SYS_MOUNT_H
             fp = setmntent("/etc/mtab", "r");
             do {
                 mnt = getmntent(fp);
@@ -1058,7 +1054,7 @@ int main(int argc, char *argv[])
             }
             while (mnt);
             endmntent(fp);
-
+#endif
             if (mnt) {
                 printf("%s is mounted on %s\n", argv[fileindex], mnt->mnt_dir);
                 uri = g_strdup_printf("%s/VIDEO_TS", mnt->mnt_dir);
@@ -1181,6 +1177,22 @@ int main(int argc, char *argv[])
     }
 #endif
 
+    gm_audio_update_device(&audio_device);
+    gm_audio_get_volume(&audio_device);
+    gm_audio_set_server_volume_update_callback(&audio_device, set_volume);
+    if (!softvol) {
+        printf("The volume on '%s' is %f\n", audio_device.description, audio_device.volume);
+        volume = audio_device.volume * 100;
+    } else {
+        audio_device.volume = volume / 100.0;
+    }
+#ifdef GTK2_12_ENABLED
+    gtk_scale_button_set_value(GTK_SCALE_BUTTON(vol_slider), audio_device.volume * 100.0);
+#else
+    gtk_range_set_value(GTK_RANGE(vol_slider), audio_device.volume * 100.0);
+#endif
+    use_volume_option = detect_volume_option();
+
     dbus_hookup(embed_window, control_id);
     show_window(embed_window);
 
@@ -1191,8 +1203,7 @@ int main(int argc, char *argv[])
         // When running as apple.com external player, don't load the default playlist
         if (control_id == 0) {
             use_remember_loc = remember_loc;
-            gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_playlist),
-                                           playlist_visible);
+            gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_playlist), playlist_visible);
         } else {
             remember_loc = FALSE;
             use_remember_loc = FALSE;
@@ -1211,8 +1222,7 @@ int main(int argc, char *argv[])
     if (single_instance && embed_window == 0) {
         if (control_id == 0) {
             use_remember_loc = remember_loc;
-            gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_playlist),
-                                           playlist_visible);
+            gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_playlist), playlist_visible);
         }
     }
 
@@ -1223,7 +1233,7 @@ int main(int argc, char *argv[])
 
         }
     }
-                        
+
     safe_to_save_default_playlist = FALSE;
     if (use_defaultpl) {
         create_folder_progress_window();
