@@ -85,8 +85,7 @@ gboolean button_release_callback(GtkWidget * widget, GdkEvent * event, gpointer
 
     event_button = (GdkEventButton *) event;
 
-    gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(list), event_button->x, event_button->y, &path,
-                                  NULL, NULL, NULL);
+    gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(list), event_button->x, event_button->y, &path, NULL, NULL, NULL);
     if (path != NULL) {
         buf = gtk_tree_path_to_string(path);
         pos = (gint) g_strtod(buf, NULL);
@@ -151,10 +150,46 @@ void playlist_set_subtitle_callback(GtkMenuItem * menuitem, void *data)
 
 }
 
+void playlist_set_audiofile_callback(GtkMenuItem * menuitem, void *data)
+{
+    GtkTreeSelection *sel;
+    GtkTreeView *view = (GtkTreeView *) data;
+    GtkTreeIter localiter;
+    gchar *audiofile;
+    GtkWidget *dialog;
+    gchar *path;
+    gchar *item;
+    gchar *p;
+
+    sel = gtk_tree_view_get_selection(view);
+
+    if (gtk_tree_selection_get_selected(sel, NULL, &localiter)) {
+        gtk_tree_model_get(GTK_TREE_MODEL(playliststore), &localiter, ITEM_COLUMN, &item, -1);
+        path = g_strdup(item);
+        p = g_strrstr(path, "/");
+        if (p != NULL)
+            p[1] = '\0';
+
+        dialog = gtk_file_chooser_dialog_new(_("Set Audio"),
+                                             GTK_WINDOW(window),
+                                             GTK_FILE_CHOOSER_ACTION_OPEN,
+                                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                             GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
+        gtk_widget_show(dialog);
+        gtk_file_chooser_set_current_folder_uri(GTK_FILE_CHOOSER(dialog), path);
+        if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
+            audiofile = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
+            gtk_list_store_set(playliststore, &localiter, AUDIOFILE_COLUMN, audiofile, -1);
+            g_free(audiofile);
+        }
+        gtk_widget_destroy(dialog);
+    }
+
+}
+
 
 gboolean playlist_drop_callback(GtkWidget * widget, GdkDragContext * dc,
-                                gint x, gint y, GtkSelectionData * selection_data,
-                                guint info, guint t, gpointer data)
+                                gint x, gint y, GtkSelectionData * selection_data, guint info, guint t, gpointer data)
 {
     gchar **list;
     gint i = 0;
@@ -165,12 +200,20 @@ gboolean playlist_drop_callback(GtkWidget * widget, GdkDragContext * dc,
      */
     if (selection_data == NULL)
         return FALSE;
+#ifdef GTK2_14_ENABLED
     if (gtk_selection_data_get_length(selection_data) < 0)
         return FALSE;
+#else
+    if (selection_data->length < 0)
+        return FALSE;
+#endif
 
     if ((info == DRAG_INFO_0) || (info == DRAG_INFO_1) || (info == DRAG_INFO_2)) {
+#ifdef GTK2_14_ENABLED
         list = g_uri_list_extract_uris((const gchar *) gtk_selection_data_get_data(selection_data));
-
+#else
+        list = g_uri_list_extract_uris((const gchar *) selection_data->data);
+#endif
         while (list[i] != NULL) {
             if (strlen(list[i]) > 0) {
                 if (is_uri_dir(list[i])) {
@@ -220,8 +263,7 @@ gboolean playlist_motion_callback(GtkWidget * widget, GdkEventMotion * event, gp
     gchar *itersubtitle;
     gchar *tip;
 
-    gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(widget), event->x, event->y, &localpath, NULL, NULL,
-                                  NULL);
+    gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(widget), event->x, event->y, &localpath, NULL, NULL, NULL);
 
     if (localpath != NULL) {
         if (gtk_tree_model_get_iter(GTK_TREE_MODEL(playliststore), &localiter, localpath)) {
@@ -356,6 +398,13 @@ void load_playlist(GtkWidget * widget, void *data)
     gtk_file_filter_add_pattern(filter, "*.m3u");
     gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), filter);
 
+    filter = gtk_file_filter_new();
+    gtk_file_filter_set_name(filter, _("MPEG Playlist (*.mxu,*.m1u,*.m4u)"));
+    gtk_file_filter_add_pattern(filter, "*.mxu");
+    gtk_file_filter_add_pattern(filter, "*.m1u");
+    gtk_file_filter_add_pattern(filter, "*.m4u");
+    gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), filter);
+
     if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
 
         filename = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(dialog));
@@ -594,9 +643,7 @@ void add_folder_to_playlist(GtkWidget * widget, void *data)
     update_gui();
     gm_pref_store_free(gm_store);
     gtk_widget_destroy(dialog);
-    message =
-        g_markup_printf_escaped(ngettext("\n\tFound %i file\n", "\n\tFound %i files\n", filecount),
-                                filecount);
+    message = g_markup_printf_escaped(ngettext("\n\tFound %i file\n", "\n\tFound %i files\n", filecount), filecount);
     g_strlcpy(idledata->media_info, message, 1024);
     g_free(message);
     g_idle_add(set_media_label, idledata);
@@ -670,10 +717,8 @@ void move_item_up(GtkWidget * widget, void *data)
             if (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(playliststore), &a, NULL, pos)) {
                 if (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(playliststore), &b, NULL, pos - 1)) {
                     gtk_list_store_swap(playliststore, &a, &b);
-                    gtk_tree_model_get(GTK_TREE_MODEL(playliststore), &a, PLAY_ORDER_COLUMN,
-                                       &a_order, -1);
-                    gtk_tree_model_get(GTK_TREE_MODEL(playliststore), &b, PLAY_ORDER_COLUMN,
-                                       &b_order, -1);
+                    gtk_tree_model_get(GTK_TREE_MODEL(playliststore), &a, PLAY_ORDER_COLUMN, &a_order, -1);
+                    gtk_tree_model_get(GTK_TREE_MODEL(playliststore), &b, PLAY_ORDER_COLUMN, &b_order, -1);
                     gtk_list_store_set(playliststore, &a, PLAY_ORDER_COLUMN, b_order, -1);
                     gtk_list_store_set(playliststore, &b, PLAY_ORDER_COLUMN, a_order, -1);
                 }
@@ -708,10 +753,8 @@ void move_item_down(GtkWidget * widget, void *data)
             if (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(playliststore), &a, NULL, pos)) {
                 if (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(playliststore), &b, NULL, pos + 1)) {
                     gtk_list_store_swap(playliststore, &a, &b);
-                    gtk_tree_model_get(GTK_TREE_MODEL(playliststore), &a, PLAY_ORDER_COLUMN,
-                                       &a_order, -1);
-                    gtk_tree_model_get(GTK_TREE_MODEL(playliststore), &b, PLAY_ORDER_COLUMN,
-                                       &b_order, -1);
+                    gtk_tree_model_get(GTK_TREE_MODEL(playliststore), &a, PLAY_ORDER_COLUMN, &a_order, -1);
+                    gtk_tree_model_get(GTK_TREE_MODEL(playliststore), &b, PLAY_ORDER_COLUMN, &b_order, -1);
                     gtk_list_store_set(playliststore, &a, PLAY_ORDER_COLUMN, b_order, -1);
                     gtk_list_store_set(playliststore, &b, PLAY_ORDER_COLUMN, a_order, -1);
 
@@ -728,8 +771,7 @@ void move_item_down(GtkWidget * widget, void *data)
 
 }
 
-gboolean playlist_select_callback(GtkTreeView * view, GtkTreePath * path,
-                                  GtkTreeViewColumn * column, gpointer data)
+gboolean playlist_select_callback(GtkTreeView * view, GtkTreePath * path, GtkTreeViewColumn * column, gpointer data)
 {
 
     if (gtk_tree_model_get_iter(GTK_TREE_MODEL(playliststore), &iter, path)) {
@@ -754,8 +796,7 @@ void repeat_callback(GtkWidget * widget, void *data)
 void shuffle_callback(GtkWidget * widget, void *data)
 {
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_edit_random),
-                                   !gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM
-                                                                   (menuitem_edit_random)));
+                                   !gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem_edit_random)));
 }
 
 void menuitem_view_playlist_callback(GtkMenuItem * menuitem, void *data)
@@ -769,8 +810,7 @@ void menuitem_view_playlist_callback(GtkMenuItem * menuitem, void *data)
 
 void undo_playlist_sort(GtkWidget * widget, void *data)
 {
-    gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(playliststore), PLAY_ORDER_COLUMN,
-                                         GTK_SORT_ASCENDING);
+    gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(playliststore), PLAY_ORDER_COLUMN, GTK_SORT_ASCENDING);
 }
 
 void create_playlist_widget()
@@ -791,6 +831,8 @@ void create_playlist_widget()
     GtkWidget *undo;
     GtkTreePath *path;
     GtkAccelGroup *accel_group;
+    GtkIconTheme *icon_theme;
+
 #ifdef GTK2_12_ENABLED
 #else
     GtkTooltips *tooltip;
@@ -825,14 +867,10 @@ void create_playlist_widget()
     }
 
     g_signal_connect(G_OBJECT(list), "row_activated", G_CALLBACK(playlist_select_callback), NULL);
-    g_signal_connect(G_OBJECT(list), "button-release-event",
-                     G_CALLBACK(button_release_callback), NULL);
-    g_signal_connect(G_OBJECT(list), "motion-notify-event",
-                     G_CALLBACK(playlist_motion_callback), NULL);
-    g_signal_connect(G_OBJECT(list), "enter-notify-event",
-                     G_CALLBACK(playlist_enter_callback), NULL);
-    g_signal_connect(G_OBJECT(list), "leave-notify-event",
-                     G_CALLBACK(playlist_leave_callback), NULL);
+    g_signal_connect(G_OBJECT(list), "button-release-event", G_CALLBACK(button_release_callback), NULL);
+    g_signal_connect(G_OBJECT(list), "motion-notify-event", G_CALLBACK(playlist_motion_callback), NULL);
+    g_signal_connect(G_OBJECT(list), "enter-notify-event", G_CALLBACK(playlist_enter_callback), NULL);
+    g_signal_connect(G_OBJECT(list), "leave-notify-event", G_CALLBACK(playlist_leave_callback), NULL);
     // Give the window the property to accept DnD
     target_entry[i].target = DRAG_NAME_0;
     target_entry[i].flags = 0;
@@ -849,8 +887,7 @@ void create_playlist_widget()
                       GTK_DEST_DEFAULT_DROP, target_entry, i, GDK_ACTION_LINK);
 
     //Connect the signal for DnD
-    g_signal_connect(GTK_OBJECT(plvbox), "drag_data_received",
-                     G_CALLBACK(playlist_drop_callback), NULL);
+    g_signal_connect(GTK_OBJECT(plvbox), "drag_data_received", G_CALLBACK(playlist_drop_callback), NULL);
 
 #ifdef GTK2_12_ENABLED
 #else
@@ -880,8 +917,7 @@ void create_playlist_widget()
     gtk_tree_view_append_column(GTK_TREE_VIEW(list), column);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(_("Artist"),
-                                                      renderer, "text", ARTIST_COLUMN, NULL);
+    column = gtk_tree_view_column_new_with_attributes(_("Artist"), renderer, "text", ARTIST_COLUMN, NULL);
     gtk_tree_view_column_set_expand(column, TRUE);
     //gtk_tree_view_column_set_max_width(column, 20);
     g_object_set(renderer, "width-chars", 20, NULL);
@@ -891,8 +927,7 @@ void create_playlist_widget()
     gtk_tree_view_append_column(GTK_TREE_VIEW(list), column);
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(_("Album"),
-                                                      renderer, "text", ALBUM_COLUMN, NULL);
+    column = gtk_tree_view_column_new_with_attributes(_("Album"), renderer, "text", ALBUM_COLUMN, NULL);
     gtk_tree_view_column_set_expand(column, TRUE);
     //gtk_tree_view_column_set_max_width(column, 20);
     g_object_set(renderer, "width-chars", 20, NULL);
@@ -903,8 +938,7 @@ void create_playlist_widget()
 
 
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(_("Length"),
-                                                      renderer, "text", LENGTH_COLUMN, NULL);
+    column = gtk_tree_view_column_new_with_attributes(_("Length"), renderer, "text", LENGTH_COLUMN, NULL);
     //gtk_tree_view_column_set_expand(column, FALSE);
     gtk_tree_view_column_set_alignment(column, 1.0);
     g_object_set(renderer, "xalign", 1.0, NULL);
@@ -913,8 +947,7 @@ void create_playlist_widget()
 
 
     renderer = gtk_cell_renderer_text_new();
-    column =
-        gtk_tree_view_column_new_with_attributes(_("Count"), renderer, "text", COUNT_COLUMN, NULL);
+    column = gtk_tree_view_column_new_with_attributes(_("Count"), renderer, "text", COUNT_COLUMN, NULL);
     //gtk_tree_view_column_set_expand(column, FALSE);
     g_object_set(renderer, "xalign", 1.0, NULL);
     gtk_tree_view_column_set_resizable(column, FALSE);
@@ -922,9 +955,7 @@ void create_playlist_widget()
     gtk_tree_view_append_column(GTK_TREE_VIEW(list), column);
 
     renderer = gtk_cell_renderer_text_new();
-    column =
-        gtk_tree_view_column_new_with_attributes(_("Order"), renderer, "text", PLAY_ORDER_COLUMN,
-                                                 NULL);
+    column = gtk_tree_view_column_new_with_attributes(_("Order"), renderer, "text", PLAY_ORDER_COLUMN, NULL);
     //gtk_tree_view_column_set_expand(column, FALSE);
     g_object_set(renderer, "xalign", 1.0, NULL);
     gtk_tree_view_column_set_resizable(column, FALSE);
@@ -939,8 +970,7 @@ void create_playlist_widget()
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, plclose, _("Close Playlist View"), NULL);
 #endif
-    gtk_container_add(GTK_CONTAINER(plclose),
-                      gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU));
+    gtk_container_add(GTK_CONTAINER(plclose), gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU));
 
     g_signal_connect_swapped(GTK_OBJECT(plclose), "clicked", G_CALLBACK(playlist_close), NULL);
 
@@ -954,8 +984,7 @@ void create_playlist_widget()
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, loadlist, _("Open Playlist"), NULL);
 #endif
-    gtk_container_add(GTK_CONTAINER(loadlist),
-                      gtk_image_new_from_stock(GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU));
+    gtk_container_add(GTK_CONTAINER(loadlist), gtk_image_new_from_stock(GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), loadlist, FALSE, FALSE, 0);
     g_signal_connect(GTK_OBJECT(loadlist), "clicked", G_CALLBACK(load_playlist), NULL);
 
@@ -966,8 +995,7 @@ void create_playlist_widget()
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, savelist, _("Save Playlist"), NULL);
 #endif
-    gtk_container_add(GTK_CONTAINER(savelist),
-                      gtk_image_new_from_stock(GTK_STOCK_SAVE, GTK_ICON_SIZE_MENU));
+    gtk_container_add(GTK_CONTAINER(savelist), gtk_image_new_from_stock(GTK_STOCK_SAVE, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), savelist, FALSE, FALSE, 0);
     g_signal_connect(GTK_OBJECT(savelist), "clicked", G_CALLBACK(save_playlist), NULL);
 
@@ -978,8 +1006,7 @@ void create_playlist_widget()
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, add, _("Add Item to Playlist"), NULL);
 #endif
-    gtk_button_set_image(GTK_BUTTON(add),
-                         gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_MENU));
+    gtk_button_set_image(GTK_BUTTON(add), gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), add, FALSE, FALSE, 0);
     g_signal_connect(GTK_OBJECT(add), "clicked", G_CALLBACK(add_to_playlist), NULL);
 
@@ -990,8 +1017,7 @@ void create_playlist_widget()
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, remove, _("Remove Item from Playlist"), NULL);
 #endif
-    gtk_button_set_image(GTK_BUTTON(remove),
-                         gtk_image_new_from_stock(GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU));
+    gtk_button_set_image(GTK_BUTTON(remove), gtk_image_new_from_stock(GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), remove, FALSE, FALSE, 0);
     g_signal_connect(GTK_OBJECT(remove), "clicked", G_CALLBACK(remove_from_playlist), list);
 
@@ -1002,8 +1028,7 @@ void create_playlist_widget()
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, add_folder, _("Add Items in Folder to Playlist"), NULL);
 #endif
-    gtk_button_set_image(GTK_BUTTON(add_folder),
-                         gtk_image_new_from_stock(GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_MENU));
+    gtk_button_set_image(GTK_BUTTON(add_folder), gtk_image_new_from_stock(GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), add_folder, FALSE, FALSE, 0);
     g_signal_connect(GTK_OBJECT(add_folder), "clicked", G_CALLBACK(add_folder_to_playlist), list);
 
@@ -1014,8 +1039,7 @@ void create_playlist_widget()
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, clear, _("Clear Playlist"), NULL);
 #endif
-    gtk_button_set_image(GTK_BUTTON(clear),
-                         gtk_image_new_from_stock(GTK_STOCK_CLEAR, GTK_ICON_SIZE_MENU));
+    gtk_button_set_image(GTK_BUTTON(clear), gtk_image_new_from_stock(GTK_STOCK_CLEAR, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), clear, FALSE, FALSE, 0);
     g_signal_connect(GTK_OBJECT(clear), "clicked", G_CALLBACK(clear_playlist), list);
 
@@ -1026,8 +1050,7 @@ void create_playlist_widget()
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, up, _("Move Item Up"), NULL);
 #endif
-    gtk_button_set_image(GTK_BUTTON(up),
-                         gtk_image_new_from_stock(GTK_STOCK_GO_UP, GTK_ICON_SIZE_MENU));
+    gtk_button_set_image(GTK_BUTTON(up), gtk_image_new_from_stock(GTK_STOCK_GO_UP, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), up, FALSE, FALSE, 0);
     g_signal_connect(GTK_OBJECT(up), "clicked", G_CALLBACK(move_item_up), list);
     gtk_widget_set_sensitive(up, FALSE);
@@ -1039,8 +1062,7 @@ void create_playlist_widget()
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, down, _("Move Item Down"), NULL);
 #endif
-    gtk_button_set_image(GTK_BUTTON(down),
-                         gtk_image_new_from_stock(GTK_STOCK_GO_DOWN, GTK_ICON_SIZE_MENU));
+    gtk_button_set_image(GTK_BUTTON(down), gtk_image_new_from_stock(GTK_STOCK_GO_DOWN, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), down, FALSE, FALSE, 0);
     g_signal_connect(GTK_OBJECT(down), "clicked", G_CALLBACK(move_item_down), list);
     gtk_widget_set_sensitive(down, FALSE);
@@ -1053,8 +1075,7 @@ void create_playlist_widget()
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, undo, _("UnSort List"), NULL);
 #endif
-    gtk_button_set_image(GTK_BUTTON(undo),
-                         gtk_image_new_from_stock(GTK_STOCK_UNDO, GTK_ICON_SIZE_MENU));
+    gtk_button_set_image(GTK_BUTTON(undo), gtk_image_new_from_stock(GTK_STOCK_UNDO, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), undo, FALSE, FALSE, 0);
     g_signal_connect(GTK_OBJECT(undo), "clicked", G_CALLBACK(undo_playlist_sort), list);
     gtk_widget_set_sensitive(undo, TRUE);
@@ -1062,8 +1083,7 @@ void create_playlist_widget()
 
     accel_group = gtk_accel_group_new();
     gtk_window_add_accel_group(GTK_WINDOW(window), accel_group);
-    gtk_widget_add_accelerator(GTK_WIDGET(remove), "clicked",
-                               accel_group, GDK_Delete, 0, GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(GTK_WIDGET(remove), "clicked", accel_group, GDK_Delete, 0, GTK_ACCEL_VISIBLE);
 
     repeat = gtk_button_new();
 #ifdef GTK2_12_ENABLED
@@ -1072,8 +1092,11 @@ void create_playlist_widget()
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, repeat, _("Loop Playlist"), NULL);
 #endif
-    gtk_button_set_image(GTK_BUTTON(repeat),
-                         gtk_image_new_from_icon_name("media-playlist-repeat", GTK_ICON_SIZE_MENU));
+    icon_theme = gtk_icon_theme_get_default();
+    if (gtk_icon_theme_has_icon(icon_theme, "media-playlist-repeat")) {
+        gtk_button_set_image(GTK_BUTTON(repeat),
+                             gtk_image_new_from_icon_name("media-playlist-repeat", GTK_ICON_SIZE_MENU));
+    }
     gtk_box_pack_start(GTK_BOX(ctrlbox), repeat, FALSE, FALSE, 0);
     g_signal_connect(GTK_OBJECT(repeat), "clicked", G_CALLBACK(repeat_callback), NULL);
     gtk_widget_set_sensitive(repeat, TRUE);
@@ -1085,9 +1108,10 @@ void create_playlist_widget()
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, shuffle, _("Shuffle Playlist"), NULL);
 #endif
-    gtk_button_set_image(GTK_BUTTON(shuffle),
-                         gtk_image_new_from_icon_name("media-playlist-shuffle",
-                                                      GTK_ICON_SIZE_MENU));
+    if (gtk_icon_theme_has_icon(icon_theme, "media-playlist-shuffle")) {
+        gtk_button_set_image(GTK_BUTTON(shuffle),
+                             gtk_image_new_from_icon_name("media-playlist-shuffle", GTK_ICON_SIZE_MENU));
+    }
     gtk_box_pack_start(GTK_BOX(ctrlbox), shuffle, FALSE, FALSE, 0);
     g_signal_connect(GTK_OBJECT(shuffle), "clicked", G_CALLBACK(shuffle_callback), NULL);
     gtk_widget_set_sensitive(shuffle, TRUE);
@@ -1101,8 +1125,7 @@ void create_playlist_widget()
     gtk_box_pack_end(GTK_BOX(closebox), plclose, FALSE, FALSE, 0);
 
     scrolled = gtk_scrolled_window_new(NULL, NULL);
-    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
-                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_container_add(GTK_CONTAINER(scrolled), list);
 
     gtk_box_pack_start(GTK_BOX(plvbox), scrolled, TRUE, TRUE, 0);
@@ -1114,18 +1137,19 @@ void create_playlist_widget()
     gtk_paned_pack2(GTK_PANED(pane), plvbox, FALSE, FALSE);
 
     gtk_widget_style_get(pane, "handle-size", &handle_size, NULL);
-    gtk_widget_set_size_request(plvbox, 300, 200);
+    gtk_widget_set_size_request(plvbox, 350, 200);
 
     playlist_popup_menu = GTK_MENU(gtk_menu_new());
-    playlist_set_subtitle =
-        GTK_MENU_ITEM(gtk_image_menu_item_new_with_mnemonic(_("_Set Subtitle")));
-    g_signal_connect(GTK_OBJECT(playlist_set_subtitle), "activate",
-                     G_CALLBACK(playlist_set_subtitle_callback), list);
+    playlist_set_subtitle = GTK_MENU_ITEM(gtk_image_menu_item_new_with_mnemonic(_("_Set Subtitle")));
+    g_signal_connect(GTK_OBJECT(playlist_set_subtitle), "activate", G_CALLBACK(playlist_set_subtitle_callback), list);
 
     gtk_menu_append(playlist_popup_menu, GTK_WIDGET(playlist_set_subtitle));
+    playlist_set_audiofile = GTK_MENU_ITEM(gtk_image_menu_item_new_with_mnemonic(_("Set Audi_o")));
+    g_signal_connect(GTK_OBJECT(playlist_set_audiofile), "activate", G_CALLBACK(playlist_set_audiofile_callback), list);
+
+    gtk_menu_append(playlist_popup_menu, GTK_WIDGET(playlist_set_audiofile));
     g_signal_connect_swapped(G_OBJECT(list),
-                             "button_press_event",
-                             G_CALLBACK(playlist_popup_handler), G_OBJECT(playlist_popup_menu));
+                             "button_press_event", G_CALLBACK(playlist_popup_handler), G_OBJECT(playlist_popup_menu));
     gtk_widget_show_all(GTK_WIDGET(playlist_popup_menu));
 
 
