@@ -33,6 +33,7 @@ GtkTooltips *playlisttip;
 
 GtkMenu *playlist_popup_menu;
 GtkMenuItem *playlist_set_subtitle;
+GtkMenuItem *playlist_set_audiofile;
 gint window_width, window_height;
 gint filecount;
 GtkWidget *up;
@@ -43,7 +44,3 @@ void update_gui();
 void menuitem_view_playlist_callback(GtkMenuItem * menuitem, void *data);
 void add_item_to_playlist_callback(gpointer data, gpointer user_data);
 void add_folder_to_playlist_callback(gpointer data, gpointer user_data);
-
-// these are in gui.c
-gint get_height();
-gint get_width();
