@@ -78,8 +78,6 @@ gboolean prev_item_in_playlist(GtkTreeIter * iter);
 gboolean next_item_in_playlist(GtkTreeIter * iter);
 void randomize_playlist(GtkListStore * store);
 void reset_playlist_order(GtkListStore * store);
-gdouble get_alsa_volume(gboolean show_details);
-gboolean set_alsa_volume(gboolean show_details, gint volume);
 gchar *seconds_to_string(gfloat seconds);
 
 gchar *get_localfile_from_uri(gchar * uri);
