@@ -41,8 +41,7 @@ void mplayer_shutdown()
         dbus_send_event("Ended", 0);
     } else {
         if (verbose > 1) {
-            printf
-                ("plugin calling mplayer shutdown when mplayer might have already been shutdown\n");
+            printf("plugin calling mplayer shutdown when mplayer might have already been shutdown\n");
         }
         send_command("quit\n", FALSE);
     }
@@ -96,8 +95,7 @@ gboolean play(void *data)
             // printf("iter is not valid, getting first one\n");
             gtk_tree_model_get_iter_first(GTK_TREE_MODEL(playliststore), &iter);
         }
-        gtk_list_store_set(playliststore, &iter, PLAYLIST_COLUMN, p->playlist, ITEM_COLUMN, p->uri,
-                           -1);
+        gtk_list_store_set(playliststore, &iter, PLAYLIST_COLUMN, p->playlist, ITEM_COLUMN, p->uri, -1);
         play_iter(&iter, 0);
     }
     g_free(p);
@@ -143,8 +141,7 @@ gboolean thread_reader_error(GIOChannel * source, GIOCondition condition, gpoint
 
     if (threaddata != NULL && threaddata->done == TRUE) {
         if (verbose)
-            printf("shutting down threadquery for %s since threaddata->done is TRUE\n",
-                   threaddata->filename);
+            printf("shutting down threadquery for %s since threaddata->done is TRUE\n", threaddata->filename);
         if (threaddata != NULL)
             g_free(threaddata);
         threaddata = NULL;
@@ -187,13 +184,11 @@ gboolean thread_reader_error(GIOChannel * source, GIOCondition condition, gpoint
     if (strstr(mplayer_output->str, "Failed to open") != NULL) {
         if (strstr(mplayer_output->str, "LIRC") == NULL &&
             strstr(mplayer_output->str, "/dev/rtc") == NULL &&
-            strstr(mplayer_output->str, "registry file") == NULL) {
+            strstr(mplayer_output->str, "VDPAU") == NULL && strstr(mplayer_output->str, "registry file") == NULL) {
             // error_msg = g_strdup(mplayer_output->str);
             if (strstr(mplayer_output->str, "<") == NULL && strstr(mplayer_output->str, ">") == NULL
                 && idledata->streaming == FALSE) {
-                error_msg =
-                    g_strdup_printf(_("Failed to open %s"),
-                                    mplayer_output->str + strlen("Failed to open "));
+                error_msg = g_strdup_printf(_("Failed to open %s"), mplayer_output->str + strlen("Failed to open "));
             }
 
             if (strstr(mplayer_output->str, "mms://") != NULL && idledata->streaming) {
@@ -233,8 +228,7 @@ gboolean thread_reader_error(GIOChannel * source, GIOCondition condition, gpoint
 
     if (strstr(mplayer_output->str, "Cannot load subtitles: ") != NULL) {
         error_msg =
-            g_strdup_printf(_("Cannot load subtitles: %s"),
-                            mplayer_output->str + strlen("Cannot load subtitles: "));
+            g_strdup_printf(_("Cannot load subtitles: %s"), mplayer_output->str + strlen("Cannot load subtitles: "));
     }
 
     if (strstr(mplayer_output->str, "Failed to initiate \"video/X-ASF-PF\" RTP subsession") != NULL) {
@@ -315,8 +309,7 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
 
     if (threaddata != NULL && threaddata->done == TRUE) {
         if (verbose)
-            printf("shutting down threadquery for %s since threaddata->done is TRUE\n",
-                   threaddata->filename);
+            printf("shutting down threadquery for %s since threaddata->done is TRUE\n", threaddata->filename);
         if (threaddata != NULL)
             g_free(threaddata);
         threaddata = NULL;
@@ -445,30 +438,30 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
             send_command("get_property sub_demux\n", TRUE);
         }
 
-		if (embed_window == 0)
-			idledata->cachepercent = 0.0;
+        if (embed_window == 0)
+            idledata->cachepercent = 0.0;
 
-		if (g_ascii_strncasecmp(vo, "gl2", strlen("gl2")) != 0) {
-		    cmd = g_strdup_printf("brightness %i\n", idledata->brightness);
-		    send_command(cmd, TRUE);
-		    g_free(cmd);
+        if (vo != NULL && g_ascii_strncasecmp(vo, "gl2", strlen("gl2")) != 0) {
+            cmd = g_strdup_printf("brightness %i\n", idledata->brightness);
+            send_command(cmd, TRUE);
+            g_free(cmd);
 
-		    cmd = g_strdup_printf("contrast %i\n", idledata->contrast);
-		    send_command(cmd, TRUE);
-		    g_free(cmd);
+            cmd = g_strdup_printf("contrast %i\n", idledata->contrast);
+            send_command(cmd, TRUE);
+            g_free(cmd);
 
-		    cmd = g_strdup_printf("gamma %i\n", idledata->gamma);
-		    send_command(cmd, TRUE);
-		    g_free(cmd);
+            cmd = g_strdup_printf("gamma %i\n", idledata->gamma);
+            send_command(cmd, TRUE);
+            g_free(cmd);
 
-		    cmd = g_strdup_printf("hue %i\n", idledata->hue);
-		    send_command(cmd, TRUE);
-		    g_free(cmd);
+            cmd = g_strdup_printf("hue %i\n", idledata->hue);
+            send_command(cmd, TRUE);
+            g_free(cmd);
 
-		    cmd = g_strdup_printf("saturation %i\n", idledata->saturation);
-		    send_command(cmd, TRUE);
-		    g_free(cmd);
-		}
+            cmd = g_strdup_printf("saturation %i\n", idledata->saturation);
+            send_command(cmd, TRUE);
+            g_free(cmd);
+        }
     }
 
     if (strstr(mplayer_output->str, "Video: no video") != NULL) {
@@ -510,8 +503,8 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
     if (strstr(mplayer_output->str, "ID_LENGTH") != 0) {
         buf = strstr(mplayer_output->str, "ID_LENGTH");
         sscanf(buf, "ID_LENGTH=%lf", &idledata->length);
-		if (idledata->streaming)
-			idledata->cachepercent = 0.0;
+        if (idledata->streaming)
+            idledata->cachepercent = 0.0;
         g_idle_add(set_progress_time, idledata);
     }
 
@@ -546,9 +539,7 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
         buf = strstr(mplayer_output->str, "ANS_volume");
         sscanf(buf, "ANS_volume=%f", &vol);
         // Need to track what the master volume is, gui is updated in make mouse invisible
-        idledata->mplayer_volume = vol;
         idledata->mute = !((gint) vol > 0);
-        g_idle_add(update_volume, idledata);
     }
 
     if (strstr(mplayer_output->str, "ANS_chapters") != 0) {
@@ -767,6 +758,12 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
         g_idle_add(set_update_gui, NULL);
     }
 
+    if (strstr(mplayer_output->str, "ID_SEEKABLE=") != 0) {
+        buf = strstr(mplayer_output->str, "ID_SEEKABLE");
+        sscanf(buf, "ID_SEEKABLE=%i", &idledata->seekable);
+        g_idle_add(set_show_seek_buttons, idledata);
+    }
+
     if (strstr(mplayer_output->str, "DVDNAV_TITLE_IS_MENU") != 0) {
         dvdnav_title_is_menu = TRUE;
     }
@@ -806,8 +803,7 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
                 }
             }
             if (g_utf8_validate(buf + 1, strlen(buf + 1), 0))
-                message =
-                    g_markup_printf_escaped("<small>\n\t<big><b>%s</b></big>\n</small>", buf + 1);
+                message = g_markup_printf_escaped("<small>\n\t<big><b>%s</b></big>\n</small>", buf + 1);
         }
         if (message) {
             // reset max values in audio meter
@@ -875,8 +871,7 @@ gboolean thread_query(gpointer data)
 
     if (threaddata != NULL && threaddata->done == TRUE) {
         if (verbose)
-            printf("shutting down threadquery for %s since threaddata->done is TRUE\n",
-                   threaddata->filename);
+            printf("shutting down threadquery for %s since threaddata->done is TRUE\n", threaddata->filename);
         g_free(threaddata);
         threaddata = NULL;
         return FALSE;
@@ -973,11 +968,16 @@ gpointer launch_player(gpointer data)
 
     // argv[arg++] = g_strdup_printf("-v");
 
-    if ((vo != NULL && strlen(vo) > 0) || (ao != NULL && strlen(ao) > 0)) {
+    if (vo != NULL && strlen(vo) > 0) {
         argv[arg++] = g_strdup_printf("-profile");
         argv[arg++] = g_strdup_printf("gnome-mplayer");
     }
 
+    if (audio_device.mplayer_ao != NULL && strlen(audio_device.mplayer_ao) > 0) {
+        argv[arg++] = g_strdup_printf("-ao");
+        argv[arg++] = g_strdup_printf("%s", audio_device.mplayer_ao);
+    }
+
     if (vo != NULL && g_ascii_strncasecmp(vo, "xvmc", strlen("xvmc")) == 0) {
         if (g_ascii_strncasecmp(threaddata->filename, "dvd://", strlen("dvd://")) == 0
             || g_ascii_strncasecmp(threaddata->filename, "dvdnav://", strlen("dvdnav://")) == 0) {
@@ -1018,29 +1018,23 @@ gpointer launch_player(gpointer data)
     argv[arg++] = g_strdup_printf("-identify");
 
     // this argument seems to cause noise in some videos
-    if (softvol) {
+    if (softvol || audio_device.type == AUDIO_TYPE_SOFTVOL) {
+        argv[arg++] = g_strdup_printf("-softvol");
         if (volume_gain != 0) {
             argv[arg++] = g_strdup_printf("-af-add");
             argv[arg++] = g_strdup_printf("volume=%i", volume_gain);
-        } else {
-            argv[arg++] = g_strdup_printf("-softvol");
         }
     }
-
+    // might want to use this only in softvol mode
     if (use_volume_option) {
         argv[arg++] = g_strdup_printf("-volume");
-        //if (idledata->mute) {
-        //    argv[arg++] = g_strdup_printf("0");
-        //} else {
         argv[arg++] = g_strdup_printf("%i", (gint) idledata->volume);
-        idledata->mplayer_volume = idledata->volume;
-        //}
     }
 
-    if (mixer != NULL && strlen(mixer) > 0) {
-        if (ao == NULL || (ao != NULL && g_ascii_strncasecmp(ao, "alsa", 4) == 0)) {
+    if (audio_device.alsa_mixer != NULL && strlen(audio_device.alsa_mixer) > 0) {
+        if (audio_device.type == AUDIO_TYPE_ALSA) {
             argv[arg++] = g_strdup_printf("-mixer-channel");
-            argv[arg++] = g_strdup_printf("%s", mixer);
+            argv[arg++] = g_strdup_printf("%s", audio_device.alsa_mixer);
         }
     }
 
@@ -1150,6 +1144,11 @@ gpointer launch_player(gpointer data)
         argv[arg++] = g_strdup_printf("%i", tv_fps);
     }
 
+    if (threaddata->audiofile != NULL && strlen(threaddata->audiofile) > 0) {
+        argv[arg++] = g_strdup_printf("-audiofile");
+        argv[arg++] = g_strdup_printf("%s", threaddata->audiofile);
+    }
+
     if (threaddata->subtitle != NULL && strlen(threaddata->subtitle) > 0) {
         argv[arg++] = g_strdup_printf("-sub");
         argv[arg++] = g_strdup_printf("%s", threaddata->subtitle);
@@ -1166,7 +1165,7 @@ gpointer launch_player(gpointer data)
         // Simply ommiting '-embeddedfonts' did not work
         // printf("demuxer = %s\n",idledata->demuxer);
         // if (!disable_embeddedfonts) {
-        if (!disable_embeddedfonts && (g_strrstr(idledata->demuxer, "mkv") || g_strrstr(idledata->demuxer, "lavfpref")) ) {
+        if (!disable_embeddedfonts && (g_strrstr(idledata->demuxer, "mkv") || g_strrstr(idledata->demuxer, "lavfpref"))) {
             argv[arg++] = g_strdup_printf("-embeddedfonts");
         } else {
             argv[arg++] = g_strdup_printf("-noembeddedfonts");
@@ -1230,6 +1229,9 @@ gpointer launch_player(gpointer data)
     case 2:
         argv[arg++] = g_strdup_printf("6");
         break;
+    case 3:
+        argv[arg++] = g_strdup_printf("8");
+        break;
     default:
         argv[arg++] = g_strdup_printf("2");
         break;
@@ -1263,11 +1265,11 @@ gpointer launch_player(gpointer data)
         argv[arg++] = g_strdup_printf("screenshot");
     }
 
-    if (idledata->device != NULL) {
+    if (idledata->device != NULL && strlen(idledata->device) > 0) {
         argv[arg++] = g_strdup_printf("-dvd-device");
         argv[arg++] = g_strdup_printf("%s", idledata->device);
     } else {
-        if (mplayer_dvd_device != NULL) {
+        if (mplayer_dvd_device != NULL && strlen(mplayer_dvd_device) > 0) {
             argv[arg++] = g_strdup_printf("-dvd-device");
             argv[arg++] = g_strdup_printf("%s", mplayer_dvd_device);
         }
@@ -1296,13 +1298,18 @@ gpointer launch_player(gpointer data)
 */
 
     if (!use_hw_audio) {
+#ifndef OS_WIN32
         argv[arg++] = g_strdup_printf("-af-add");
         argv[arg++] = g_strdup_printf("export=%s:512", idledata->af_export);
+#endif
     }
 
     if (g_strrstr(threaddata->filename, "apple.com")) {
         argv[arg++] = g_strdup_printf("-user-agent");
-        argv[arg++] = g_strdup_printf("QuickTime/7.6.4");
+        argv[arg++] = g_strdup_printf("QuickTime/7.6.9");
+    } else {
+        argv[arg++] = g_strdup_printf("-user-agent");
+        argv[arg++] = g_strdup_printf("GnomeMplayer/" VERSION);
     }
 
     /* disable msg stuff to make sure extra console characters don't mess around */
@@ -1330,8 +1337,7 @@ gpointer launch_player(gpointer data)
     state = PAUSED;
     error = NULL;
     ok = g_spawn_async_with_pipes(NULL, argv, NULL,
-                                  G_SPAWN_SEARCH_PATH,
-                                  NULL, NULL, &pid, &std_in, &std_out, &std_err, &error);
+                                  G_SPAWN_SEARCH_PATH, NULL, NULL, &pid, &std_in, &std_out, &std_err, &error);
 
     if (error != NULL) {
         printf("error code = %i - %s\n", error->code, error->message);
@@ -1374,14 +1380,12 @@ gpointer launch_player(gpointer data)
         g_io_channel_set_close_on_unref(channel_out, TRUE);
         g_io_channel_set_close_on_unref(channel_err, TRUE);
         watch_in_id =
-            g_io_add_watch_full(channel_out, G_PRIORITY_LOW, G_IO_IN | G_IO_HUP, thread_reader,
-                                threaddata, NULL);
+            g_io_add_watch_full(channel_out, G_PRIORITY_LOW, G_IO_IN | G_IO_HUP, thread_reader, threaddata, NULL);
         watch_err_id =
             g_io_add_watch_full(channel_err, G_PRIORITY_LOW, G_IO_IN | G_IO_ERR | G_IO_HUP,
                                 thread_reader_error, threaddata, NULL);
         watch_in_hup_id =
-            g_io_add_watch_full(channel_out, G_PRIORITY_LOW, G_IO_ERR | G_IO_HUP, thread_complete,
-                                threaddata, NULL);
+            g_io_add_watch_full(channel_out, G_PRIORITY_LOW, G_IO_ERR | G_IO_HUP, thread_complete, threaddata, NULL);
 //        watch_in_id = g_io_add_watch(channel_in, G_IO_IN, thread_reader, NULL);
 //        watch_err_id = g_io_add_watch(channel_err, G_IO_IN | G_IO_ERR | G_IO_HUP, thread_reader_error, NULL);
 //        watch_in_hup_id = g_io_add_watch(channel_in, G_IO_ERR | G_IO_HUP, thread_complete, NULL);
@@ -1478,8 +1482,7 @@ gpointer launch_player(gpointer data)
                 if (loop) {
                     if (first_item_in_playlist(&iter)) {
                         gtk_tree_model_get(GTK_TREE_MODEL(playliststore), &iter, ITEM_COLUMN,
-                                           &filename, COUNT_COLUMN, &count, PLAYLIST_COLUMN,
-                                           &playlist, -1);
+                                           &filename, COUNT_COLUMN, &count, PLAYLIST_COLUMN, &playlist, -1);
                         g_strlcpy(idledata->info, filename, 4096);
                         g_idle_add(set_media_info, idledata);
                         p = (PlayData *) g_malloc(sizeof(PlayData));
@@ -1495,6 +1498,7 @@ gpointer launch_player(gpointer data)
 
                     // nothing is on the playlist and we are not looping so ask plugin for next item
                     if (embed_window != 0 || control_id != 0) {
+                        js_state = STATE_MEDIAENDED;
                         dbus_send_event("MediaComplete", 0);
                         dbus_open_next();
                     }
